aboutsummaryrefslogtreecommitdiffstats
path: root/plumbing/transport/common.go
diff options
context:
space:
mode:
Diffstat (limited to 'plumbing/transport/common.go')
-rw-r--r--plumbing/transport/common.go9
1 files changed, 5 insertions, 4 deletions
diff --git a/plumbing/transport/common.go b/plumbing/transport/common.go
index 41813bf..83fd5a3 100644
--- a/plumbing/transport/common.go
+++ b/plumbing/transport/common.go
@@ -49,6 +49,8 @@ type Session interface {
SetAuth(auth AuthMethod) error
// AdvertisedReferences retrieves the advertised references for a
// repository.
+ // If the repository does not exist, returns ErrRepositoryNotFound.
+ // If the repository exists, but is empty, returns ErrEmptyRemoteRepository.
AdvertisedReferences() (*packp.AdvRefs, error)
io.Closer
}
@@ -75,10 +77,9 @@ type FetchPackSession interface {
// In that order.
type SendPackSession interface {
Session
- // UpdateReferences sends an update references request and returns a
- // writer to be used for packfile writing.
- //TODO: Complete signature.
- SendPack() (io.WriteCloser, error)
+ // UpdateReferences sends an update references request and a packfile
+ // reader and returns a ReportStatus and error.
+ SendPack(*packp.ReferenceUpdateRequest) (*packp.ReportStatus, error)
}
type Endpoint url.URL